@@ -77,6 +77,7 @@ public:
     KAutoSaveFile            *m_autosave;
 
     bool                      m_dirty;                ///<dirty bit
+    bool                      m_isReadOnly;
 
     // save these to document
     QList<KEduVocIdentifier>  m_identifiers;          ///<list of identifiers
@@ -117,7 +118,9 @@ public:
      *   @param flags Describes how to deal with locked file etc.
      *   @return ErrorCode where NoError is success
      *   */
-    KEduVocDocument::ErrorCode initializeKAutoSave(KAutoSaveFile &autosave,  QString const &fpath,  FileHandlingFlags flags) const;
+    KEduVocDocument::ErrorCode initializeKAutoSave(KAutoSaveFile &autosave,
+						   QString const &fpath,
+						   FileHandlingFlags flags) const;
 };
 
 KEduVocDocument::KEduVocDocumentPrivate::~KEduVocDocumentPrivate()
@@ -133,7 +136,9 @@ KEduVocDocument::KEduVocDocumentPrivate::~KEduVocDocumentPrivate()
 void KEduVocDocument::KEduVocDocumentPrivate::init()
 {
     delete m_lessonContainer;
-    m_lessonContainer = new KEduVocLesson(i18nc("The top level lesson which contains all other lessons of the document.", "Document Lesson"));
+    m_lessonContainer = new KEduVocLesson(i18nc("The top level lesson which contains all other lessons of the document.",
+						"Document Lesson"),
+					  q);
     m_lessonContainer->setContainerType(KEduVocLesson::Lesson);
     delete m_wordTypeContainer;
     m_wordTypeContainer = new KEduVocWordType(i18n( "Word types" ));
@@ -146,6 +151,7 @@ void KEduVocDocument::KEduVocDocumentPrivate::init()
     m_extraSizeHints.clear();
     m_sizeHints.clear();
     m_dirty = false;
+    m_isReadOnly = false;
     m_queryorg = "";
     m_querytrans = "";
     m_autosave->setManagedFile( i18n( "Untitled" ) );
@@ -188,7 +194,8 @@ KEduVocDocument::ErrorCode KEduVocDocument::KEduVocDocumentPrivate::initializeKA
 
 
 KEduVocDocument::KEduVocDocument( QObject *parent )
-        : QObject( parent ), d( new KEduVocDocumentPrivate( this ) )
+    : QObject(parent)
+    , d(new KEduVocDocumentPrivate(this))
 {
 }
 
@@ -243,9 +250,17 @@ KEduVocDocument::ErrorCode KEduVocDocument::open( const KUrl& url,  FileHandling
         return FileDoesNotExist;
     }
 
-    ErrorCode autosaveError = d->initializeKAutoSave( *d->m_autosave,  temporaryFile, flags );
-    if ( autosaveError != NoError) {
-        return autosaveError;
+    if (flags & FileOpenReadOnly) {
+	d->m_isReadOnly = true;
+    }
+
+    ErrorCode autosaveError = NoError;
+
+    if (!d->m_isReadOnly) {
+	autosaveError = d->initializeKAutoSave( *d->m_autosave,  temporaryFile, flags );
+	if ( autosaveError != NoError) {
+	    return autosaveError;
+	}
     }
 
     QIODevice * f = KFilterDev::deviceForFile( temporaryFile );
@@ -275,8 +290,11 @@ KEduVocDocument::ErrorCode KEduVocDocument::open( const KUrl& url,  FileHandling
     return errStatus;
 }
 
-void KEduVocDocument::close() {
-    d->m_autosave->releaseLock();
+void KEduVocDocument::close()
+{
+    if (!d->m_isReadOnly) {
+	d->m_autosave->releaseLock();
+    }
 }
 
 /// @todo When the API major version number increments remove this function
@@ -292,8 +310,12 @@ int KEduVocDocument::saveAs( const KUrl & url, FileType ft, const QString & gene
     return err;
 }
 
-KEduVocDocument::ErrorCode KEduVocDocument::saveAs( const KUrl & url, FileType ft, FileHandlingFlags flags)
+KEduVocDocument::ErrorCode KEduVocDocument::saveAs( const KUrl & url, FileType ft,
+						    FileHandlingFlags flags)
 {
+    if (d->m_isReadOnly) {
+	return FileIsReadOnly;
+    }
 
     KUrl tmp( url );
 
